@@ -1,9 +1,8 @@
 from . import (  # noqa: F401
-    deband, easing, exprfuncs, mask, misc, noise, other, oyster, traiNNing, transitions, tweaking, types, utils
+    deband, easing, mask, misc, noise, other, oyster, traiNNing, transitions, tweaking, types, utils
 )
 from .deband import *  # noqa: F401, F403
 from .easing import *  # noqa: F401, F403
-from .exprfuncs import *  # noqa: F401, F403
 from .mask import *  # noqa: F401, F403
 from .misc import *  # noqa: F401, F403
 from .noise import *  # noqa: F401, F403
